%---------------------------------------------------------------------------
% Identification part
%---------------------------------------------------------------------------

\NeedsTeXFormat{LaTeX2e}

\ProvidesClass{polytex}[2001/04/25]

\def\fileversion{2.41}

%%% Commande de cration d'un nouveau triplet \ifcmd \cmdTrue \cmdFalse.
%%% Les dfinitions sont maintenant globales.
%%%
%%% \poly@newif{cmd}{True} ou \poly@newif{cmd}{False} permet d'initialiser
%%% le booleen \cmd  la valeur correspondante.

\def\poly@newif#1#2{%
   \expandafter\newif\csname if#1\endcsname%
   \expandafter\def\csname #1True\endcsname{\global\csname#1true\endcsname}%
   \expandafter\def\csname #1False\endcsname{\global\csname#1false\endcsname}%
   \csname #1#2\endcsname%
}

\RequirePackage{ifthen}
\RequirePackage{version}

\poly@newif{macintosh}{False}

\poly@newif{transparent}{False}
\poly@newif{polycopie}{False}
\poly@newif{propre}{False}
\poly@newif{intermediaire}{True}
\poly@newif{solutions}{False}
\poly@newif{impression}{False}
\poly@newif{ecran}{True}


\DeclareOption{10pt}{%
   \PassOptionsToClass{10pt}{book}
}

\DeclareOption{11pt}{%
   \PassOptionsToClass{11pt}{book}
}

\DeclareOption{12pt}{%
   \PassOptionsToClass{12pt}{book}
}

\DeclareOption{impression}{%
	\impressionTrue
	\ecranFalse	
}

\DeclareOption{ecran}{%
   	\impressionFalse
	\ecranTrue
}

\DeclareOption{intermediaire}{%
   \intermediaireTrue%
}

\DeclareOption{final}{%
   \intermediaireFalse%
}

\DeclareOption{polycopie}{%
   \polycopieTrue%
   \transparentFalse%
}

\DeclareOption{poly}{%
   \polycopieTrue%
   \transparentFalse%
}

\DeclareOption{transparent}{%
   \polycopieFalse%
   \transparentTrue%
}

\DeclareOption{slides}{%
   \polycopieFalse%
   \transparentTrue%
}
\DeclareOption{propre}{%
   \propreTrue%
}

\DeclareOption{sale}{%
   \propreFalse%
}

\DeclareOption{solutions}{%
   \solutionsTrue%   
}

\DeclareOption*{%
   \PassOptionsToPackage{\CurrentOption}{polyTheme}
}


%---------------------------------------------------------------------------
% Execution of options
%---------------------------------------------------------------------------

\ExecuteOptions{ecran,final,polycopie,sale,10pt}

\ProcessOptions

%---------------------------------------------------------------------------
% Choix de l'encodage des fonts : T1 au lieu de OT1 pour eviter de nombreux
% problemes lies au caracteres accentues.
%---------------------------------------------------------------------------
%---------------------------------------------------------------------------
% Choix de l'encodage des caracteres du fichier source 
% suivant la plate-forme.
%
% Pour Unix et DOS, l'encodage des
% caracteres accentues est pris en compte automatiquement par le codage T1.
% Cependant, pour le Macintosh, le codage etant different, on doit utiliser 
% en plus  \RequirePackage[mac]{inputenc}.
%---------------------------------------------------------------------------

\ifmacintosh
   \RequirePackage[T1]{fontenc}
   \RequirePackage[mac]{inputenc}
   \ifpropre
      \def\prefixe{:aux:}
   \else
      \def\prefixe{:}
   \fi
   \def\separateur{:}
\else
   \RequirePackage[T1]{fontenc}
   \ifpropre
       \def\prefixe{aux/}
   \else
       \def\prefixe{./}
   \fi
   \def\separateur{/}
\fi

\xdef\jobslides{\jobname -slides}
\xdef\jobpoly{\jobname -poly}

\let\oldjobname=\jobname

\iftransparent
   \xdef\jobname{\prefixe\oldjobname -slides}
   \typeout{jobname = \jobname}
\else
   \xdef\jobname{\prefixe\oldjobname -poly}
   \typeout{jobname = \jobname}
\fi

%---------------------------------------------------------------------------
% Class loading
%---------------------------------------------------------------------------

\ifimpression
	\ifpolycopie
		\PassOptionsToClass{twoside}{book}
	\else
		\PassOptionsToClass{oneside}{book}
	\fi
\else
	\PassOptionsToClass{oneside}{book}
\fi	

\LoadClass{book}

%
\ifx\pdfoutput\undefined        % on teste si on est dans latex
   \PassOptionsToPackage{xdvi}{color}
   \PassOptionsToPackage{dvips}{graphicx}
   \def\poly@extension{dvi}%
\else
   \def\poly@extension{pdf}%
\fi

\RequirePackage{graphicx}
   
\ifx\pdfoutput\undefined        % on teste si on est dans latex
   \DeclareGraphicsExtensions{.ps,.eps,.pstex}
\fi


\RequirePackage{color}
\RequirePackage[colorlinks,hyperindex]{hyperref}
\RequirePackage{epsfig}
\RequirePackage{multind}
\RequirePackage{calc}

%% Chemin par dfaut pour les figures

\ifmacintosh
   \graphicspath{{:figures:}}
\else
   \graphicspath{{figures/}}
\fi

% Support des fonts Computer Modern en codage T1


\RequirePackage{ae}
\RequirePackage[cm]{aeguill}
\RequirePackage[english,frenchb]{babel}

%
% Choix du type de support, polycopi ou transparent
%

\iftransparent
   \RequirePackage{polySlides}
\else
   \RequirePackage{polyCop}
\fi

%% Chargement du thme ('vanillia' par dfaut)

\RequirePackage{polyTheme}

\endinput
